#!/usr/bin/python3

from time import sleep
import dbus

bus = dbus.SystemBus()

snapper = dbus.Interface(bus.get_object('org.opensuse.Snapper', '/org/opensuse/Snapper'),
                         dbus_interface='org.opensuse.Snapper')


snapper.LockConfig("root")

sleep(10)

snapper.UnlockConfig("root")



#!/usr/bin/python3

from time import gmtime, asctime
from pwd import getpwuid
import dbus

bus = dbus.SystemBus()

snapper = dbus.Interface(bus.get_object('org.opensuse.Snapper', '/org/opensuse/Snapper'),
                         dbus_interface='org.opensuse.Snapper')


snapshot = snapper.GetSnapshot("root", 1)

print(snapshot[0], snapshot[1], snapshot[2], asctime(gmtime(snapshot[3])),
      getpwuid(snapshot[4])[0], snapshot[5], snapshot[6], end='')
for k, v in snapshot[7].items():
    print("", "%s=%s" % (k, v), end='')
print()



#!/usr/bin/python3

import dbus

bus = dbus.SystemBus()

snapper = dbus.Interface(bus.get_object('org.opensuse.Snapper', '/org/opensuse/Snapper'),
                         dbus_interface='org.opensuse.Snapper')


config_name = "root"
num_pre = 52
num_post = 53

snapper.CreateComparison(config_name, num_pre, num_post)

files = snapper.GetFiles(config_name, num_pre, num_post)

for file in files:
    print(file[0], file[1])



#!/usr/bin/python3

import dbus
from dbus.mainloop.glib import DBusGMainLoop
from gi.repository.GLib import MainLoop


DBusGMainLoop(set_as_default=True)

bus = dbus.SystemBus()

snapper = dbus.Interface(bus.get_object('org.opensuse.Snapper', '/org/opensuse/Snapper'),
                         dbus_interface='org.opensuse.Snapper')


class MessageListener:

    def __init__(self):

        signals = {
            "ConfigCreated" : self.config_created,
            "ConfigModified" : self.config_modified,
            "ConfigDeleted" : self.config_deleted,
            "SnapshotCreated" : self.snapshot_created,
            "SnapshotModified" : self.snapshot_modified,
            "SnapshotsDeleted" : self.snapshots_deleted,
        }

        for signal, handler in signals.items():
            snapper.connect_to_signal(signal, handler)


    def config_created(self, config):
        print("ConfigCreated", config)

    def config_modified(self, config):
        print("ConfigModified", config)

    def config_deleted(self, config):
        print("ConfigDeleted", config)

    def snapshot_created(self, config, number):
        print("SnapshotCreated", config, number)

    def snapshot_modified(self, config, number):
        print("SnapshotModified", config, number)

    def snapshots_deleted(self, config, numbers):
        print("SnapshotsDeleted", config, end='')
        for number in numbers:
            print("", number, end='')
        print()


MessageListener()

MainLoop().run()



#!/usr/bin/python3

from time import gmtime, asctime
from pwd import getpwuid
import dbus

bus = dbus.SystemBus()

snapper = dbus.Interface(bus.get_object('org.opensuse.Snapper', '/org/opensuse/Snapper'),
                         dbus_interface='org.opensuse.Snapper')


snapshots = snapper.ListSnapshots("root")

for snapshot in snapshots:
    print(snapshot[0], snapshot[1], snapshot[2], end='')

    if snapshot[3] != -1:
        print("", asctime(gmtime(snapshot[3])), end='')
    else:
        print("", "now", end='')

    print("", getpwuid(snapshot[4])[0], snapshot[5], snapshot[6], end='')
    for k, v in snapshot[7].items():
        print("", "%s=%s" % (k, v), end='')
    print()



#!/usr/bin/python3

import dbus

bus = dbus.SystemBus()

snapper = dbus.Interface(bus.get_object('org.opensuse.Snapper', '/org/opensuse/Snapper'),
                         dbus_interface='org.opensuse.Snapper')


print(snapper.CreateSingleSnapshot("root", "test", "", { "id" : "123" }))
